Your Font/Glyphs

# Your font contains the following glyphs

The generated SVG font can be imported back to IcoMoon for modification.

# Class Names

icon-home icon-pencil icon-camera icon-camera-2 icon-play icon-music icon-headphones icon-phone icon-phone-hang-up icon-address-book icon-notebook icon-envelop icon-pushpin icon-bubble icon-bubble-2 icon-bubbles icon-bubbles-2 icon-bubbles-3 icon-user icon-users icon-quotes-left icon-spinner icon-search icon-cogs icon-wrench icon-unlocked icon-lock icon-lock-2 icon-key icon-key-2 icon-zoom-out icon-zoom-in icon-cog icon-remove icon-remove-2 icon-eye icon-eye-blocked icon-attachment icon-globe icon-heart icon-happy icon-thumbs-up icon-smiley icon-tongue icon-sad icon-wink icon-wondering icon-confused icon-shocked icon-evil icon-angry icon-cool icon-grin icon-info icon-notification icon-warning icon-spell-check icon-volume-high icon-volume-medium icon-volume-low icon-volume-mute icon-volume-mute-2 icon-volume-decrease icon-volume-increase icon-bold icon-underline icon-italic icon-strikethrough icon-new-tab icon-youtube icon-close icon-blocked icon-cancel-circle icon-minus icon-plus icon-checkbox-checked icon-checkbox-unchecked icon-checkbox-partial icon-radio-checked icon-radio-unchecked icon-info-2 icon-newspaper icon-image icon-offline icon-busy